@@ -2,7 +2,7 @@ package Crypt::PK::DSA;
 
 use strict;
 use warnings;
-our $VERSION = '0.051';
+our $VERSION = '0.053';
 
 require Exporter; our @ISA = qw(Exporter); ### use Exporter 'import';
 our %EXPORT_TAGS = ( all => [qw( dsa_encrypt dsa_decrypt dsa_sign_message dsa_verify_message dsa_sign_hash dsa_verify_hash )] );
@@ -33,7 +33,7 @@ sub generate_key {
     $p =~ s/^0x//;
     $q =~ s/^0x//;
     $g =~ s/^0x//;
-    return $self->_generate_key_pqg($p, $q, $g);
+    return $self->_generate_key_pqg_hex($p, $q, $g);
   }
   elsif (@_ == 1 && ref $_[0] eq 'SCALAR') {
     my $data = ${$_[0]};
